## $Id: interfaces.py 8072 2012-04-09 07:53:53Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Customized interfaces of the university application package.
"""

from zope import schema
from waeup.kofa.applicants.interfaces import IApplicantBaseData
from waeup.kofa.students.vocabularies import nats_vocab
from waeup.custom.interfaces import lgas_vocab
from waeup.custom.interfaces import MessageFactory as _

class IUGApplicant(IApplicantBaseData):
    """An undergraduate applicant.

    """

    nationality = schema.Choice(
        source = nats_vocab,
        title = _(u'Nationality'),
        required = False,
        )
    lga = schema.Choice(
        source = lgas_vocab,
        title = _(u'State/LGA (Nigerians only)'),
        required = False,
        )

# This ordering doesn't work properly.
IUGApplicant[
    'nationality'].order =  IApplicantBaseData['sex'].order
IUGApplicant[
    'lga'].order =  IUGApplicant['nationality'].order

class IPGApplicant(IApplicantBaseData):
    """A postgraduate applicant.

    """

    nationality = schema.Choice(
        source = nats_vocab,
        title = _(u'Nationality'),
        required = False,
        )
    lga = schema.Choice(
        source = lgas_vocab,
        title = _(u'State/LGA (Nigerians only)'),
        required = False,
        )
    employer = schema.TextLine(
        title = _(u'Employer'),
        required = False,
        readonly = False,
        )

# This ordering doesn't work properly.
IPGApplicant[
    'nationality'].order =  IApplicantBaseData['sex'].order
IPGApplicant[
    'lga'].order =  IPGApplicant['nationality'].order
IPGApplicant[
    'student_id'].order =  IPGApplicant['notice'].order

class IApplicant(IUGApplicant,IPGApplicant):
    """An interface for both types of applicants.

    """

    def loggerInfo(ob_class, comment):
        """Adds an INFO message to the log file
        """

    def createStudent():
        """Create a student object from applicatnt data
        and copy applicant object.
        """

class IUGApplicantEdit(IUGApplicant):
    """An undergraduate applicant interface for editing.

    Here we can repeat the fields from base data and set the
    `required` and `readonly` attributes to True to further restrict
    the data access. Or we can allow only certain certificates to be
    selected by choosing the appropriate source.

    We cannot omit fields here. This has to be done in the
    respective form page.
    """

class IPGApplicantEdit(IPGApplicant):
    """A postgraduate applicant interface for editing.

    Here we can repeat the fields from base data and set the
    `required` and `readonly` attributes to True to further restrict
    the data access. Or we can allow only certain certificates to be
    selected by choosing the appropriate source.

    We cannot omit fields here. This has to be done in the
    respective form page.
    """
